@@ -1,5 +1,3 @@
-import urllib
-
 from aiohttp import web
 from aiohttp_middlewares import cors_middleware  # type: ignore
 
@@ -104,25 +102,13 @@ async def authorize(request: web.Request) -> web.Response:
     cookies = request.cookies
     if cookies.get("anyscale-token") == request.config_dict["auth_token"]:
         return web.Response(text="Authorized", status=200)
-    else:
-        # Prometheus does not set a cookie
-        if request.headers.get("X-Forwarded-Uri") == "/metrics":
-            ref = request.headers.get("Referer", "")
-            token_list = urllib.parse.parse_qs(urllib.parse.urlsplit(ref).query).get(
-                "token", []
-            )
-            if (
-                len(token_list) == 1
-                and token_list[0] == request.config_dict["auth_token"]
-            ):
-                return web.Response(text="Authorized", status=200)
-        unauthorized_message = (
-            "Unauthorized. Please navigate to this resource through the cluster's page in the Anyscale "
-            "product. Doing so will automatically authorize this request from a web browser. Please "
-            "include the `anyscale-token` in the cookies if not performing this request from a web "
-            "browser."
-        )
-        return web.Response(text=unauthorized_message, status=401)
+    unauthorized_message = (
+        "Unauthorized. Please navigate to this resource through the cluster's page in the Anyscale "
+        "product. Doing so will automatically authorize this request from a web browser. Please "
+        "include the `anyscale-token` in the cookies if not performing this request from a web "
+        "browser."
+    )
+    return web.Response(text=unauthorized_message, status=401)
 
 
 def make_auth_proxy_app(auth_token: str) -> web.Application:
