@@ -10,6 +10,7 @@ from anyscale.api import (
     ApiClientWrapperInternal,
     AsyncApiClientWrapperExternal,
     configure_open_api_client_headers,
+    configure_tcp_keepalive,
     format_api_exception,
 )
 from anyscale.cli_logger import BlockLogger
@@ -94,6 +95,7 @@ class AuthenticationBlock:
         cookie = f"cli_token={self.credentials}"
         api_client = ApiClientWrapperInternal(configuration, cookie=cookie)
         configure_open_api_client_headers(api_client, "CLI")
+        configure_tcp_keepalive(api_client)
         api_instance = openapi_client.DefaultApi(api_client)
         return api_instance
 
@@ -118,12 +120,18 @@ class AuthenticationBlock:
             )
         )
         configure_open_api_client_headers(api_client, "CLI")
-
+        configure_tcp_keepalive(api_client)
         api_instance = anyscale_client.DefaultApi(api_client)
         return api_instance
 
     def _validate_credentials_format(self, credentials: str) -> None:
-        if not credentials.startswith("sss_"):
+        # Existing token style
+        if credentials.startswith("sss_"):
+            return
+        # Future token style
+        elif credentials.startswith("a") and credentials.count("_") > 0:
+            return
+        else:
             url = anyscale.util.get_endpoint("/credentials")
             raise click.ClickException(
                 "Your user credentials are invalid. Please go to "
