@@ -30,11 +30,14 @@ from anyscale.authenticate import get_auth_api_client
 # 1. This module is passed to the autoscaler on the head node as an external node provider
 # 2. Import paths are different for different versions of ray
 try:
-    from ray.autoscaler._private.providers import _get_node_provider, _NODE_PROVIDERS
+    from ray.autoscaler._private.providers import (  # pylint:disable=private-import
+        _get_node_provider,
+        _NODE_PROVIDERS,
+    )
     from ray.autoscaler.node_provider import NodeProvider
 except ModuleNotFoundError:
     from ray.autoscaler.aws.node_provider import NodeProvider
-    from ray.autoscaler.node_provider import (
+    from ray.autoscaler.node_provider import (  # pylint:disable=private-import
         get_node_provider as _get_node_provider,
         NODE_PROVIDERS as _NODE_PROVIDERS,
     )
