@@ -62,7 +62,9 @@ class BlockLogger:
             assert (
                 self.current_block == block_label
             ), f"Attempting to log to block {block_label}, but block {self.current_block} is currently open."
-            print(*msg)
+            print(
+                *msg, file=sys.stderr,
+            )
         else:
             print(
                 "{}{}(anyscale +{}){} ".format(
@@ -72,8 +74,11 @@ class BlockLogger:
                     colorama.Style.RESET_ALL,
                 ),
                 end="",
+                file=sys.stderr,
+            )
+            print(
+                *msg, file=sys.stderr,
             )
-            print(*msg)
 
     def debug(self, *msg: str) -> None:
         if not self.log_output:
@@ -94,11 +99,8 @@ class BlockLogger:
         if not self.log_output:
             return
         print(
-            "{}{}(anyscale +{}){} ".format(
-                colorama.Style.NORMAL,
-                colorama.Fore.YELLOW,
-                self._time_string(),
-                colorama.Style.RESET_ALL,
+            "{}{}[Warning]{} ".format(
+                colorama.Style.NORMAL, colorama.Fore.YELLOW, colorama.Style.RESET_ALL,
             ),
             end="",
             file=sys.stderr,
@@ -134,17 +136,6 @@ class _ConsoleLog(BlockLogger):
                 colorama.Style.RESET_ALL,
             ),
             end="",
+            file=sys.stderr,
         )
-        print(*msg)
-
-    def warning(self, *msg: str) -> None:
-        print(
-            "{}{}(anyscale +{}){} ".format(
-                colorama.Style.NORMAL,
-                colorama.Fore.YELLOW,
-                self._time_string(),
-                colorama.Style.RESET_ALL,
-            ),
-            end="",
-        )
-        print(*msg)
+        print(*msg, file=sys.stderr)
