@@ -109,6 +109,17 @@ def cloud_set_default(
     required=False,
     type=int,
 )
+@click.option(
+    "--vpc-peering-ip-range", help="IP range for VPC peering.", required=False
+)
+@click.option(
+    "--vpc-peering-target-project-id",
+    help="Project ID of the target VPC.",
+    required=False,
+)
+@click.option(
+    "--vpc-peering-target-vpc-id", help="VPC ID of the target VPC.", required=False
+)
 def setup_cloud(
     bring_cloud_account: str,
     provider: str,
@@ -116,6 +127,9 @@ def setup_cloud(
     name: str,
     yes: bool,
     gcp_folder_id: Optional[int],
+    vpc_peering_ip_range: Optional[str],
+    vpc_peering_target_project_id: Optional[str],
+    vpc_peering_target_vpc_id: Optional[str],
 ) -> None:
     CloudController().setup_cloud(
         is_aioa=bring_cloud_account == "no",
@@ -124,6 +138,9 @@ def setup_cloud(
         name=name,
         yes=yes,
         folder_id=gcp_folder_id,
+        vpc_peering_ip_range=vpc_peering_ip_range,
+        vpc_peering_target_project_id=vpc_peering_target_project_id,
+        vpc_peering_target_vpc_id=vpc_peering_target_vpc_id,
     )
 
 
