@@ -173,7 +173,7 @@ def auth_start(auth_token: Optional[str]) -> None:
 )
 @click.option(
     "--host",
-    help="Anyscale host used to instantiate anyscale openapi (beta.anyscale.com for example)",
+    help="Anyscale host used to instantiate anyscale openapi (console.anyscale.com for example)",
     type=str,
     required=True,
 )
