@@ -2,9 +2,10 @@
 Fetches data required and formats output for `anyscale cloud` commands.
 """
 
+import ipaddress
 import json
 import os
-from typing import Optional
+from typing import Any, Dict, Optional
 
 import boto3
 from click import ClickException, prompt
@@ -16,10 +17,11 @@ from anyscale.cloud import get_cloud_id_and_name, get_cloud_json_from_id
 import anyscale.conf
 from anyscale.controllers.base_controller import BaseController
 from anyscale.formatters import clouds_formatter
-from anyscale.util import (
+from anyscale.util import (  # pylint:disable=private-import
     _CACHED_GCP_REGIONS,
     _get_role,
     _resource,
+    _update_external_ids_for_policy,
     confirm,
     get_available_regions,
     launch_gcp_cloud_setup,
@@ -79,6 +81,63 @@ class CloudController(BaseController):
 
         return str(output)
 
+    def verify_vpc_peering(
+        self,
+        yes: bool,
+        vpc_peering_ip_range: Optional[str],
+        vpc_peering_target_project_id: Optional[str],
+        vpc_peering_target_vpc_id: Optional[str],
+    ) -> None:
+        if (
+            vpc_peering_ip_range
+            or vpc_peering_target_project_id
+            or vpc_peering_target_vpc_id
+        ):
+            if not vpc_peering_ip_range:
+                raise ClickException("Please specify a VPC peering IP range.")
+            if not vpc_peering_target_project_id:
+                raise ClickException("Please specify a VPC peering target project ID.")
+            if not vpc_peering_target_vpc_id:
+                raise ClickException("Please specify a VPC peering target VPC ID.")
+        else:
+            return
+
+        try:
+            valid_ip_network = ipaddress.IPv4Network(vpc_peering_ip_range)
+        except ValueError:
+            raise ClickException(f"{vpc_peering_ip_range} is not a valid IP address.")
+        # https://cloud.google.com/vpc/docs/vpc#valid-ranges
+        allowed_ip_ranges = [
+            ipaddress.IPv4Network("10.0.0.0/8"),
+            ipaddress.IPv4Network("172.16.0.0/12"),
+            ipaddress.IPv4Network("192.168.0.0/16"),
+        ]
+
+        for allowed_ip_range in allowed_ip_ranges:
+            if valid_ip_network.subnet_of(allowed_ip_range):
+                break
+        else:
+            raise ClickException(
+                f"{vpc_peering_ip_range} is not a allowed private IP address range for GCP. The allowed IP ranges are 10.0.0.0/8, 172.16.0.0/12, and 192.168.0.0/16. For more info, see https://cloud.google.com/vpc/docs/vpc#valid-ranges"
+            )
+
+        if (
+            valid_ip_network.num_addresses
+            < ipaddress.IPv4Network("192.168.0.0/16").num_addresses
+        ):
+            raise ClickException(
+                f"{vpc_peering_ip_range} is not a valid IP range. The minimum size is /16"
+            )
+
+        if not yes:
+            confirm(
+                f"\nYou selected to create a VPC peering connection to VPC {vpc_peering_target_vpc_id} in GCP project {vpc_peering_target_project_id}."
+                f"This will create a VPC peering connection from your Anyscale GCP project to the target project ({vpc_peering_target_project_id})."
+                "You will need to manually create the peering connection from the target project to your Anyscale GCP project after the anyscale cloud is created.\n"
+                "Continue cloud setup?",
+                False,
+            )
+
     def setup_cloud(
         self,
         is_aioa: bool,
@@ -87,6 +146,9 @@ class CloudController(BaseController):
         name: str,
         yes: bool = False,
         folder_id: Optional[int] = None,
+        vpc_peering_ip_range: Optional[str] = None,
+        vpc_peering_target_project_id: Optional[str] = None,
+        vpc_peering_target_vpc_id: Optional[str] = None,
     ) -> None:
         """
         Sets up a cloud provider
@@ -125,8 +187,22 @@ class CloudController(BaseController):
                     type=int,
                     show_default=False,
                 )
+
+            self.verify_vpc_peering(
+                yes,
+                vpc_peering_ip_range,
+                vpc_peering_target_project_id,
+                vpc_peering_target_vpc_id,
+            )
             # TODO: interactive setup process through the CLI?
-            launch_gcp_cloud_setup(name=name, region=region, folder_id=folder_id)
+            launch_gcp_cloud_setup(
+                name=name,
+                region=region,
+                folder_id=folder_id,
+                vpc_peering_ip_range=vpc_peering_ip_range,
+                vpc_peering_target_project_id=vpc_peering_target_project_id,
+                vpc_peering_target_vpc_id=vpc_peering_target_vpc_id,
+            )
         else:
             raise ClickException(
                 f"Invalid Cloud provider: {provider}. Available providers are [aws, gcp]."
@@ -188,7 +264,7 @@ class CloudController(BaseController):
         )
 
         anyscale_aws_account = response.result.anyscale_aws_account
-        anyscale_aws_iam_role_policy = {
+        anyscale_aws_iam_role_policy: Dict[str, Any] = {
             "Version": "2012-10-17",
             "Statement": {
                 "Sid": "1",
@@ -215,12 +291,21 @@ class CloudController(BaseController):
 
         self.log.info(f"Using IAM role {role.arn}")
 
-        self.api_client.create_cloud_api_v2_clouds_post(
+        created_cloud = self.api_client.create_cloud_api_v2_clouds_post(
             write_cloud=WriteCloud(
                 provider="AWS", region=region, credentials=role.arn, name=name,
             )
         )
 
+        # NOTE: We update this _after_ cloud creation because this External ID MUST
+        # come from Anyscale, not the customer. We are using the `cloud_id` as it is unique per cloud.
+        # https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_create_for-user_externalid.html
+        new_policy = _update_external_ids_for_policy(
+            role.assume_role_policy_document, created_cloud.result.id
+        )
+
+        role.AssumeRolePolicy().update(PolicyDocument=json.dumps(new_policy))
+
     def setup_aws_ray_role(self, region: str, role_name: str) -> None:
         iam = boto3.resource("iam", region_name=region)
 
