@@ -11,7 +11,7 @@ from anyscale.client.openapi_client import CreateProductionService, ProductionJo
 from anyscale.controllers.base_controller import BaseController
 from anyscale.controllers.job_controller import JobConfig, JobController
 from anyscale.project import find_project_root, get_project_id, ProjectDefinition
-from anyscale.util import get_endpoint
+from anyscale.util import get_endpoint, PROJECT_NAME_ENV_VAR
 
 
 class ServiceConfig(JobConfig):
@@ -31,18 +31,6 @@ class ServiceController(BaseController):
     def deploy(
         self, service_config_file: str, name: Optional[str], description: Optional[str]
     ) -> None:
-        # Check directory of .anyscale.yaml to decide whether to use default project.
-        root_dir = find_project_root(os.getcwd())
-        if root_dir is not None:
-            project_definition = ProjectDefinition(root_dir)
-            project_id = get_project_id(project_definition.root)
-        else:
-            default_project = self.anyscale_api_client.get_default_project().result
-            project_id = default_project.id
-            self.log.info(
-                f"No project context detected, so using default project {project_id}."
-            )
-
         if not os.path.exists(service_config_file):
             raise click.ClickException(f"Config file {service_config_file} not found.")
 
@@ -50,6 +38,30 @@ class ServiceController(BaseController):
             config_dict = yaml.safe_load(f)
 
         service_config = ServiceConfig.parse_obj(config_dict)
+        project_id = service_config.project_id
+
+        # If project id is not specified, try to infer it
+        if not project_id:
+            # Check directory of .anyscale.yaml to decide whether to use default project.
+            root_dir = find_project_root(os.getcwd())
+            if root_dir is not None:
+                project_definition = ProjectDefinition(root_dir)
+                project_id = get_project_id(project_definition.root)
+                project_name = self.anyscale_api_client.get_project(
+                    project_id
+                ).result.name
+                self.log.warning(
+                    ".anyscale.yaml has been detected in this project directory. The functionality of "
+                    "using this file to select the project has been deprecated, and will be removed "
+                    f"in April 2022. Please instead specify `project_id: {project_id}` in the service config file. "
+                    "The project name can also be specified by setting the environment variable "
+                    f'`{PROJECT_NAME_ENV_VAR}="{project_name}"`.'
+                )
+            else:
+                default_project = self.anyscale_api_client.get_default_project().result
+                project_id = default_project.id
+                self.log.info("No project specified. Continuing without a project.")
+
         config_object = ProductionJobConfig(
             entrypoint=service_config.entrypoint,
             runtime_env=service_config.runtime_env,
