@@ -1,4 +1,5 @@
 from contextlib import contextmanager
+from copy import deepcopy
 import datetime
 import json
 import logging
@@ -32,6 +33,7 @@ from anyscale.shared_anyscale_utils.util import get_container_name
 logger = logging.getLogger(__file__)
 
 BOTO_MAX_RETRIES = 5
+PROJECT_NAME_ENV_VAR = "ANYSCALE_PROJECT_NAME"
 
 log = BlockLogger()  # Anyscale CLI Logger
 
@@ -212,12 +214,33 @@ def get_available_regions() -> List[str]:
     return [region["RegionName"] for region in client.describe_regions()["Regions"]]
 
 
-def launch_gcp_cloud_setup(name: str, region: str, folder_id: Optional[int]) -> None:
+def launch_gcp_cloud_setup(
+    name: str,
+    region: str,
+    folder_id: Optional[int],
+    vpc_peering_ip_range: Optional[str],
+    vpc_peering_target_project_id: Optional[str],
+    vpc_peering_target_vpc_id: Optional[str],
+) -> None:
     # TODO: enforce uniqueness for user's clouds
     quote_safe_name = quote_sanitize(name, safe="")
-    query_params = {"region": region}
+    query_params = {
+        "region": region,
+    }
     if folder_id:
         query_params["folder_id"] = str(folder_id)
+    if (
+        vpc_peering_ip_range
+        and vpc_peering_target_project_id
+        and vpc_peering_target_vpc_id
+    ):
+        query_params.update(
+            {
+                "vpc_peering_ip_range": vpc_peering_ip_range,
+                "vpc_peering_target_project_id": vpc_peering_target_project_id,
+                "vpc_peering_target_vpc_id": vpc_peering_target_vpc_id,
+            }
+        )
     # TODO: Replace this with a proper endpoint
     endpoint = f"/api/v2/clouds/gcp/create/{quote_safe_name}?{urlencode(query_params)}"
     full_url = get_endpoint(endpoint)
@@ -517,19 +540,6 @@ def wait_for_head_node_start(
         retry_count += 1
 
 
-def download_anyscale_wheel(api_client: DefaultApi, session_id: str) -> None:
-    wheel_resp = api_client.session_get_anyscale_wheel_api_v2_sessions_session_id_anyscale_wheel_get(
-        session_id=session_id, _preload_content=False
-    )
-    wheel_path_raw = wheel_resp.headers["content-disposition"]
-    assert "filename" in wheel_path_raw, "Error getting anyscale wheel"
-    wheel_path = wheel_path_raw.split("filename=")[1].strip('"')
-    os.makedirs(os.path.dirname(wheel_path), exist_ok=True)
-    with open(wheel_path, "wb+") as f:
-        f.write(wheel_resp.data)
-        f.flush()
-
-
 def validate_cluster_configuration(
     cluster_config_file_name: str,
     cluster_config: Optional[DefaultApi] = None,
@@ -775,3 +785,26 @@ def validate_non_negative_arg(ctx, param, value):
             f"Please specify a non-negative value for {param.opts[0]}"
         )
     return value
+
+
+def _update_external_ids_for_policy(policy: Dict[str, Any], new_external_id: str):
+    """Gets All External IDs From policy Dict."""
+    policy = deepcopy(policy)
+    external_ids = [
+        statement.setdefault("Condition", {})
+        .setdefault("StringEquals", {})
+        .setdefault("sts:ExternalId", [])
+        for statement in policy.get("Statement", [])
+    ]
+    external_ids = [
+        [i, new_external_id] if isinstance(i, str) else i + [new_external_id]
+        for i in external_ids
+    ]
+
+    _ = [
+        policy["Statement"][i]["Condition"]["StringEquals"].update(
+            {"sts:ExternalId": external_ids[i]}
+        )
+        for i in range(len(policy.get("Statement", [])))
+    ]
+    return policy
