@@ -1,7 +1,7 @@
 import asyncio
 from typing import Dict, List
 
-from anyscale.api import instantiate_api_client
+from anyscale.authenticate import get_auth_api_client
 from anyscale.client.openapi_client.api.default_api import DefaultApi
 from anyscale.client.openapi_client.models.session_command_types import (
     SessionCommandTypes,
@@ -21,9 +21,9 @@ class CommandPersister:
     """
 
     def __init__(self, cli_token: str, host: str, session_id: str):
-        self.api_client: DefaultApi = instantiate_api_client(
+        self.api_client: DefaultApi = get_auth_api_client(
             cli_token=cli_token, host=host
-        )
+        ).api_client
         self.cli_token = cli_token
         self.host = host
         self.session_id = session_id
