@@ -17,6 +17,10 @@ from anyscale.client.openapi_client import (
     SessionStateData,
     UserInfo,
 )
+from anyscale.sdk.anyscale_client.models.cluster_compute import ClusterCompute
+from anyscale.sdk.anyscale_client.models.cluster_compute_config import (
+    ClusterComputeConfig,
+)
 
 
 @pytest.fixture()
@@ -31,6 +35,21 @@ def base_mock_anyscale_api_client() -> Mock:
     return mock_anyscale_api_client
 
 
+@pytest.fixture()
+def mock_auth_api_client(
+    base_mock_api_client: Mock, base_mock_anyscale_api_client: Mock
+):
+    mock_auth_api_client = Mock(
+        api_client=base_mock_api_client,
+        anyscale_api_client=base_mock_anyscale_api_client,
+    )
+    with patch.multiple(
+        "anyscale.controllers.base_controller",
+        get_auth_api_client=Mock(return_value=mock_auth_api_client),
+    ):
+        yield
+
+
 @pytest.fixture()
 def mock_api_client_with_session(
     base_mock_api_client: Mock, session_test_data: Session
@@ -70,6 +89,7 @@ def project_test_data() -> Project:
         directory_name="/directory/name",
         active_sessions=0,
         last_activity_at=datetime.now(tz=timezone.utc),
+        is_default=False,
     )
 
 
@@ -88,6 +108,54 @@ def session_test_data() -> Session:
     )
 
 
+@pytest.fixture(scope="module")
+def compute_config_test_data() -> ClusterComputeConfig:
+    return ClusterComputeConfig(
+        cloud_id="cld_123",
+        head_node_type={
+            "instance_type": "m5.2xlarge",
+            "name": "head-node-type",
+            "resources": None,
+        },
+        max_workers=20,
+        region="us-west-2",
+        worker_node_types=[
+            {
+                "instance_type": "m5.4xlarge",
+                "max_workers": 10,
+                "min_workers": None,
+                "name": "worker-node-type-0",
+                "resources": None,
+                "use_spot": False,
+            },
+            {
+                "instance_type": "g4dn.4xlarge",
+                "max_workers": 10,
+                "min_workers": None,
+                "name": "worker-node-type-1",
+                "resources": None,
+                "use_spot": False,
+            },
+        ],
+    )
+
+
+@pytest.fixture(scope="module")
+def cluster_compute_test_data(
+    compute_config_test_data: ClusterComputeConfig,
+) -> ClusterCompute:
+    return ClusterCompute(
+        id="cpt_123",
+        name="compute_config_name",
+        creator_id="user_123",
+        organization_id="org_123",
+        project_id="prj_123",
+        created_at=datetime.now(tz=timezone.utc),
+        last_modified_at=datetime.now(tz=timezone.utc),
+        config=compute_config_test_data,
+    )
+
+
 @pytest.fixture(scope="module")
 def session_start_error_test_data() -> Session:
     return Session(
