@@ -1,5 +1,5 @@
 from typing import Any, Dict, List, Optional
-from unittest.mock import ANY, Mock, patch
+from unittest.mock import ANY, call, Mock, patch
 
 import pytest
 
@@ -9,6 +9,8 @@ from anyscale.sdk.anyscale_client import (
     StartClusterOptions,
     UpdateCluster,
 )
+from anyscale.sdk.anyscale_client.models import ListResponseMetadata
+from anyscale.sdk.anyscale_client.models.cloud_list_response import CloudListResponse
 
 
 @pytest.fixture
@@ -128,24 +130,27 @@ def test_create_or_update_session_data(
     idle_timeout: Optional[int],
 ):
     mock_cluster = Mock(state="Running", id="test_cluster_id")
-    mock_prepare_cluster_block.api_client.list_sessions_api_v2_sessions_get = Mock(
-        return_value=Mock(results=[mock_cluster] if cluster_exists else [])
-    )
+    mock_get_cluster = Mock(return_value=(mock_cluster if cluster_exists else None))
     mock_prepare_cluster_block._validate_new_cluster_compute_and_env_match_existing_cluster = Mock(
         return_value=start_required
     )
 
-    mock_prepare_cluster_block._create_or_update_session_data(
-        "test_cluster_name",
-        "test_project_id",
-        "test_build_id",
-        "test_compute_template_id",
-        idle_timeout,
-        None,
-    )
+    with patch.multiple(
+        "anyscale.connect_utils.prepare_cluster", get_cluster=mock_get_cluster
+    ):
+        mock_prepare_cluster_block._create_or_update_session_data(
+            "test_cluster_name",
+            "test_project_id",
+            "test_build_id",
+            "test_compute_template_id",
+            idle_timeout,
+            None,
+        )
 
-    mock_prepare_cluster_block.api_client.list_sessions_api_v2_sessions_get.assert_called_once_with(
-        project_id="test_project_id", active_only=False, name="test_cluster_name"
+    mock_get_cluster.assert_called_once_with(
+        mock_prepare_cluster_block.anyscale_api_client,
+        "test_project_id",
+        "test_cluster_name",
     )
 
     if not cluster_exists:
@@ -216,15 +221,13 @@ def test_get_cluster_build(mock_prepare_cluster_block, cluster_env_name: Optiona
     )
 
     assert (
-        mock_prepare_cluster_block._get_cluster_build(
-            "test_project_id", cluster_env_name, None
-        )
+        mock_prepare_cluster_block._get_cluster_build(cluster_env_name, None)
         == mock_build
     )
 
     if cluster_env_name:
         mock_prepare_cluster_block._get_cluster_env_build.assert_called_once_with(
-            "test_project_id", cluster_env_name, None
+            cluster_env_name, None
         )
     else:
         mock_prepare_cluster_block._get_default_cluster_env_build.assert_called_once_with()
@@ -252,14 +255,14 @@ def test_get_cluster_env_build(
     if clust_env_revision == 1:
         assert (
             mock_prepare_cluster_block._get_cluster_env_build(
-                "test_project_id", "test_cluster_env_name", clust_env_revision
+                "test_cluster_env_name", clust_env_revision
             )
             == mock_build1
         )
     else:
         assert (
             mock_prepare_cluster_block._get_cluster_env_build(
-                "test_project_id", "test_cluster_env_name", clust_env_revision
+                "test_cluster_env_name", clust_env_revision
             )
             == mock_build2
         )
@@ -307,13 +310,19 @@ def test_build_cluster_env_if_needed(
 
 
 @pytest.mark.parametrize("cluster_compute_name", [None, "test_cluster_compute_name"])
+@pytest.mark.parametrize("cluster_compute_dict", [None, {"cloud_id": "mock_cloud_id"}])
+@pytest.mark.parametrize("cloud_name", [None, "test_cloud_name"])
 def test_get_cluster_compute_id(
-    mock_prepare_cluster_block, cluster_compute_name: Optional[str]
+    mock_prepare_cluster_block,
+    cluster_compute_name: Optional[str],
+    cluster_compute_dict: Optional[Dict[str, str]],
+    cloud_name: Optional[str],
 ):
     mock_prepare_cluster_block._get_cloud_id = Mock(return_value="test_cloud_id")
-    mock_config_obj = Mock()
+    mock_default_config_obj = Mock()
+    mock_config_obj_from_cluster_compute_dict = Mock()
     mock_prepare_cluster_block.anyscale_api_client.get_default_compute_config = Mock(
-        return_value=Mock(result=mock_config_obj)
+        return_value=Mock(result=mock_default_config_obj)
     )
     mock_prepare_cluster_block._register_compute_template = Mock(
         return_value="mock_registered_template"
@@ -322,9 +331,15 @@ def test_get_cluster_compute_id(
         return_value="mock_cluster_compute_template"
     )
 
-    observed_result = mock_prepare_cluster_block._get_cluster_compute_id(
-        "test_project_id", cluster_compute_name, None, "test_cloud_name"
-    )
+    with patch.multiple(
+        "anyscale.connect_utils.prepare_cluster",
+        ComputeTemplateConfig=Mock(
+            return_value=mock_config_obj_from_cluster_compute_dict
+        ),
+    ):
+        observed_result = mock_prepare_cluster_block._get_cluster_compute_id(
+            "test_project_id", cluster_compute_name, cluster_compute_dict, cloud_name
+        )
 
     if cluster_compute_name:
         mock_prepare_cluster_block._get_cluster_compute_id_from_name.assert_called_once_with(
@@ -332,12 +347,16 @@ def test_get_cluster_compute_id(
         )
         assert observed_result == "mock_cluster_compute_template"
     else:
-        mock_prepare_cluster_block._get_cloud_id.assert_called_once_with(
-            "test_project_id", "test_cloud_name"
-        )
-        mock_prepare_cluster_block.anyscale_api_client.get_default_compute_config.assert_called_once_with(
-            "test_cloud_id"
-        )
+        if cluster_compute_dict:
+            mock_config_obj = mock_config_obj_from_cluster_compute_dict
+        else:
+            mock_prepare_cluster_block._get_cloud_id.assert_called_once_with(
+                "test_project_id", cloud_name
+            )
+            mock_prepare_cluster_block.anyscale_api_client.get_default_compute_config.assert_called_once_with(
+                "test_cloud_id"
+            )
+            mock_config_obj = mock_default_config_obj
         mock_prepare_cluster_block._register_compute_template.assert_called_once_with(
             "test_project_id", mock_config_obj
         )
@@ -551,13 +570,43 @@ def test_validate_new_cluster_compute_and_env_match_existing_cluster(
         assert observed_result
 
 
-@pytest.mark.parametrize("cluster_needs_start", [True])
+def test_get_all_clouds(mock_prepare_cluster_block) -> None:
+    mock_cloud_1 = Mock()
+    mock_cloud_1.name = "cloud_1"
+    mock_cloud_2 = Mock()
+    mock_cloud_2.name = "cloud_2"
+
+    mock_prepare_cluster_block.anyscale_api_client.search_clouds.side_effect = [
+        CloudListResponse(
+            results=[mock_cloud_1],
+            metadata=ListResponseMetadata(
+                total=2, next_paging_token="next_paging_token"
+            ),
+        ),
+        CloudListResponse(
+            results=[mock_cloud_2], metadata=ListResponseMetadata(total=2),
+        ),
+    ]
+
+    all_clouds = mock_prepare_cluster_block._get_all_clouds()
+    assert all_clouds == [mock_cloud_1, mock_cloud_2]
+    mock_prepare_cluster_block.anyscale_api_client.search_clouds.assert_has_calls(
+        [
+            call({"paging": {"count": 50}}),
+            call({"paging": {"count": 50, "paging_token": "next_paging_token"}}),
+        ]
+    )
+
+
+@pytest.mark.parametrize("cluster_needs_start", [True, False])
 @pytest.mark.parametrize("cluster_name", ["test_cluster_name", None])
 @pytest.mark.parametrize("cluster_compute_name", ["test_cluster_compute_name", None])
+@pytest.mark.parametrize("cluster_env_name", ["test_cluster_env_name", None])
 def test_init(
     cluster_needs_start: bool,
     cluster_name: Optional[str],
     cluster_compute_name: Optional[str],
+    cluster_env_name: Optional[str],
 ):
     if not cluster_needs_start and not cluster_name:
         return
@@ -567,7 +616,7 @@ def test_init(
         cloud_id="mock_cloud_id", compute_template_id="mock_cluster_compute_id"
     )
     mock_cluster.name = "test_cluster_name"
-    mock_build_cluster_env_if_needed = Mock(return_value="mock_cluster_env_name")
+    mock_build_cluster_env_if_needed = Mock(return_value=cluster_env_name)
     mock_get_cluster_build = Mock(return_value=Mock(id="mock_build_id"))
     mock_get_cloud_id = Mock(return_value="mock_cloud_id")
     mock_get_cluster_compute_id = Mock(return_value="mock_cluster_compute_id")
@@ -575,6 +624,10 @@ def test_init(
     mock_create_cluster = Mock(return_value="test_cluster_name")
     mock_validate_new_cluster_compute_and_env_match_existing_cluster = Mock()
     mock_log_cluster_configs = Mock()
+    mock_cluster_compute_dict = Mock()
+    mock_force_rebuild = Mock()
+    mock_cluster_env_dict = Mock()
+    mock_cluster_env_revision = Mock()
 
     with patch.multiple(
         "anyscale.connect_utils.prepare_cluster.PrepareClusterBlock",
@@ -599,14 +652,14 @@ def test_init(
             allow_public_internet_traffic=None,
             needs_update=False,
             cluster_compute_name=cluster_compute_name,
-            cluster_compute_dict="test_cluster_compute_dict",
+            cluster_compute_dict=mock_cluster_compute_dict,
             cloud_name="test_cloud_name",
             build_pr=None,
-            force_rebuild=None,
+            force_rebuild=mock_force_rebuild,
             build_commit=None,
-            cluster_env_name="test_cluster_env_name",
-            cluster_env_dict="test_cluster_env_dict",
-            cluster_env_revision="test_cluster_env_revision",
+            cluster_env_name=cluster_env_name,
+            cluster_env_dict=mock_cluster_env_dict,
+            cluster_env_revision=mock_cluster_env_revision,
             ray=Mock(),
         )
         assert prepare_cluster_block.cluster_name == "test_cluster_name"
@@ -619,27 +672,30 @@ def test_init(
             "test_project_id",
             None,
             None,
-            "test_cluster_env_dict",
-            "test_cluster_env_name",
-            None,
-        )
-        mock_get_cluster_build.assert_called_once_with(
-            "test_project_id", "mock_cluster_env_name", "test_cluster_env_revision"
+            mock_cluster_env_dict,
+            cluster_env_name,
+            mock_force_rebuild,
         )
+        if cluster_env_name or not cluster_name:
+            mock_get_cluster_build.assert_called_once_with(
+                cluster_env_name, mock_cluster_env_revision
+            )
+            build_id = "mock_build_id"
+        else:
+            build_id = mock_cluster.build_id
+
         mock_get_cloud_id.assert_called_once_with("test_project_id", "test_cloud_name")
         if cluster_compute_name:
             mock_get_cluster_compute_id.assert_called_once_with(
                 "test_project_id",
                 cluster_compute_name,
-                "test_cluster_compute_dict",
+                mock_cluster_compute_dict,
                 "test_cloud_name",
             )
-        mock_wait_for_app_build.assert_called_once_with(
-            "test_project_id", "mock_build_id"
-        )
+        mock_wait_for_app_build.assert_called_once_with("test_project_id", build_id)
         mock_create_cluster.assert_called_once_with(
             project_id="test_project_id",
-            build_id="mock_build_id",
+            build_id=build_id,
             compute_template_id="mock_cluster_compute_id",
             cluster_name=cluster_name,
             autosuspend_timeout=10,
@@ -652,3 +708,4 @@ def test_init(
         mock_log_cluster_configs.assert_called_once_with(
             mock_cluster, mock_cluster.build_id, mock_cluster.compute_template_id, ANY
         )
+        mock_create_cluster.assert_not_called()
