@@ -1,4 +1,4 @@
-from typing import List, Optional
+from typing import List, Optional, Tuple
 from unittest.mock import Mock, patch
 
 from click import ClickException
@@ -49,6 +49,7 @@ def mock_role() -> Mock:
 
     mock_role.arn = "ARN"
     mock_role.attach_policy = Mock()
+    mock_role.assume_role_policy_document = {}
 
     return mock_role
 
@@ -110,7 +111,12 @@ def test_setup_cloud_gcp(mock_auth_api_client) -> None:
         )
 
         mock_launch_gcp_cloud_setup.assert_called_once_with(
-            region="us-west1", name="test-gcp", folder_id=None,
+            region="us-west1",
+            name="test-gcp",
+            folder_id=None,
+            vpc_peering_ip_range=None,
+            vpc_peering_target_project_id=None,
+            vpc_peering_target_vpc_id=None,
         )
 
         mock_launch_gcp_cloud_setup.reset_mock()
@@ -125,10 +131,142 @@ def test_setup_cloud_gcp(mock_auth_api_client) -> None:
         )
 
         mock_launch_gcp_cloud_setup.assert_called_once_with(
-            region="us-west1", name="test-gcp", folder_id=1234,
+            region="us-west1",
+            name="test-gcp",
+            folder_id=1234,
+            vpc_peering_ip_range=None,
+            vpc_peering_target_project_id=None,
+            vpc_peering_target_vpc_id=None,
         )
 
 
+@pytest.mark.parametrize(
+    "vpc_peering_options",
+    [
+        ("10.0.0.0/12", "project_id", "vpc_id"),
+        ("10.0.0.0/12", None, "vpc_id"),
+        ("10.0.0.0/12", "project_id", None),
+    ],
+)
+def test_setup_cloud_gcp_vpc_peering(mock_auth_api_client, vpc_peering_options) -> None:
+    (
+        vpc_peering_ip_range,
+        vpc_peering_target_project_id,
+        vpc_peering_target_vpc_id,
+    ) = vpc_peering_options
+    mock_launch_gcp_cloud_setup = Mock(return_value=None)
+    with patch.multiple(
+        "anyscale.controllers.cloud_controller",
+        launch_gcp_cloud_setup=mock_launch_gcp_cloud_setup,
+    ):
+        cloud_controller = CloudController()
+        if vpc_peering_target_project_id is None or vpc_peering_target_vpc_id is None:
+            with pytest.raises(ClickException):
+                cloud_controller.setup_cloud(
+                    is_aioa=False,
+                    provider="gcp",
+                    region=None,
+                    name="test-gcp",
+                    yes=True,
+                    vpc_peering_ip_range=vpc_peering_ip_range,
+                    vpc_peering_target_project_id=vpc_peering_target_project_id,
+                    vpc_peering_target_vpc_id=vpc_peering_target_vpc_id,
+                )
+        else:
+            cloud_controller.setup_cloud(
+                is_aioa=False,
+                provider="gcp",
+                region=None,
+                name="test-gcp",
+                yes=True,
+                vpc_peering_ip_range=vpc_peering_ip_range,
+                vpc_peering_target_project_id=vpc_peering_target_project_id,
+                vpc_peering_target_vpc_id=vpc_peering_target_vpc_id,
+            )
+
+        if vpc_peering_target_project_id is None or vpc_peering_target_vpc_id is None:
+            return
+
+        mock_launch_gcp_cloud_setup.assert_called_once_with(
+            region="us-west1",
+            name="test-gcp",
+            folder_id=None,
+            vpc_peering_ip_range=vpc_peering_ip_range,
+            vpc_peering_target_project_id=vpc_peering_target_project_id,
+            vpc_peering_target_vpc_id=vpc_peering_target_vpc_id,
+        )
+
+        mock_launch_gcp_cloud_setup.reset_mock()
+
+        cloud_controller.setup_cloud(
+            is_aioa=False,
+            provider="gcp",
+            region=None,
+            name="test-gcp",
+            yes=True,
+            folder_id=1234,
+            vpc_peering_ip_range=vpc_peering_ip_range,
+            vpc_peering_target_project_id=vpc_peering_target_project_id,
+            vpc_peering_target_vpc_id=vpc_peering_target_vpc_id,
+        )
+
+        mock_launch_gcp_cloud_setup.assert_called_once_with(
+            region="us-west1",
+            name="test-gcp",
+            folder_id=1234,
+            vpc_peering_ip_range=vpc_peering_ip_range,
+            vpc_peering_target_project_id=vpc_peering_target_project_id,
+            vpc_peering_target_vpc_id=vpc_peering_target_vpc_id,
+        )
+
+
+@pytest.mark.parametrize(
+    "vpc_peering_options,error_output",
+    [
+        (
+            ("not_an_ip_address", "project_id", "vpc_id"),
+            "not_an_ip_address is not a valid IP address.",
+        ),
+        (
+            ("10.0.0.0/20", "project_id", "vpc_id"),
+            "10.0.0.0/20 is not a valid IP range. The minimum size is /16",
+        ),
+        (
+            ("42.0.0.0/10", "project_id", "vpc_id"),
+            "42.0.0.0/10 is not a allowed private IP address range for GCP",
+        ),
+    ],
+)
+def test_setup_cloud_gcp_vpc_peering_validation(
+    mock_auth_api_client, vpc_peering_options: Tuple[str, str, str], error_output: str
+) -> None:
+    (
+        vpc_peering_ip_range,
+        vpc_peering_target_project_id,
+        vpc_peering_target_vpc_id,
+    ) = vpc_peering_options
+    mock_launch_gcp_cloud_setup = Mock(return_value=None)
+    with patch.multiple(
+        "anyscale.controllers.cloud_controller",
+        launch_gcp_cloud_setup=mock_launch_gcp_cloud_setup,
+    ):
+        cloud_controller = CloudController()
+
+        with pytest.raises(ClickException) as e:
+            cloud_controller.setup_cloud(
+                is_aioa=False,
+                provider="gcp",
+                region=None,
+                name="test-gcp",
+                yes=True,
+                vpc_peering_ip_range=vpc_peering_ip_range,
+                vpc_peering_target_project_id=vpc_peering_target_project_id,
+                vpc_peering_target_vpc_id=vpc_peering_target_vpc_id,
+            )
+
+        assert error_output in e.value.message
+
+
 def test_setup_cloud_gcp_bad_region(mock_auth_api_client) -> None:
     mock_confirm = Mock(side_effect=ClickException("aborted"))
     with patch.multiple(
@@ -200,12 +338,13 @@ def test_missing_name_and_id(mock_auth_api_client) -> None:
         cloud_controller.get_cloud_config(None, None)
 
 
-def test_setup_cross_region(mock_auth_api_client) -> None:
-    mock_api_client.get_anyscale_aws_account_api_v2_clouds_anyscale_aws_account_get = Mock(
+def test_setup_cross_region(mock_auth_api_client, cloud_test_data: Cloud) -> None:
+    mock_get_aws_account = Mock(
         return_value=AnyscaleawsaccountResponse(
             result=AnyscaleAWSAccount(anyscale_aws_account="aws_account_type")
         )
     )
+    mock_create_cloud = Mock(return_value=CloudResponse(result=cloud_test_data))
     mocked_role = mock_role()
 
     with patch.multiple(
@@ -213,9 +352,15 @@ def test_setup_cross_region(mock_auth_api_client) -> None:
         _get_role=Mock(return_value=mocked_role),
     ):
         cloud_controller = CloudController()
+        cloud_controller.api_client.get_anyscale_aws_account_api_v2_clouds_anyscale_aws_account_get = (
+            mock_get_aws_account
+        )
+        cloud_controller.api_client.create_cloud_api_v2_clouds_post = mock_create_cloud
         cloud_controller.setup_aws_cross_account_role("us-west-2", "name")
+
     cloud_controller.api_client.get_anyscale_aws_account_api_v2_clouds_anyscale_aws_account_get.assert_called_once()
     mocked_role.attach_policy.assert_called()
+    mocked_role.AssumeRolePolicy.assert_called()
 
 
 @pytest.mark.parametrize(
